##  What’s Changing
The changes affect the following endpoint on the Self-Built Software Discovery API:
Method | Endpoint | Schema
---|---|---
POST |  /factSheets/{factSheetId}/sboms |  [Reference![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Ftechnology-discovery%2Fv1%2Fopenapi%2Fswagger-ui%2Findex.html%23%2FSBOM%2Fleanix-v1-factsheets-sboms-ingest "https://eu.leanix.net/services/technology-discovery/v1/openapi/swagger-ui/index.html#/SBOM/leanix-v1-factsheets-sboms-ingest")


We're also adding a new endpoint for tracking the processing job status.
Here's what's changing:
  * [Response Status Code](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c72fe7a441014abecf824ae4d7efe__response_status_code)
  * [Enhanced Response Payload](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c72fe7a441014abecf824ae4d7efe__enhanced_response_payload)
  * [New Endpoint for Tracking the Job Status](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c72fe7a441014abecf824ae4d7efe__new_endpoint_for_tracking_the_job_status)
